==> haskell-bencode-0.6.0.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bencode
version: 0.6.0.0
id: bencode-0.6.0.0-4adAakYOeSQ63HyXPcE1PE
key: bencode-0.6.0.0-4adAakYOeSQ63HyXPcE1PE
license: BSD3
copyright: (c) 2005-2009, David Himmelstrup,
           2006 Lemmih <lemmih@gmail.com>,
           2005 Jesper Louis Andersen <jlouis@mongers.org>
maintainer: Christopher Reichert <creichert07@gmail.com>
synopsis: Parser and printer for bencoded data.
description:
    Parser and printer for bencoded data.
    .
    Bencode (pronounced like B encode) is the encoding used by the
    peer-to-peer file sharing system BitTorrent for storing and
    transmitting loosely structured data.
category: Text
author: Lemmih (lemmih@gmail.com), Jesper Louis Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
abi: 7a27047cf8b02b04f1cd6f10fcf1675e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/bencode-0.6.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/bencode-0.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/bencode-0.6.0.0
hs-libraries: HSbencode-0.6.0.0-4adAakYOeSQ63HyXPcE1PE
depends:
    base-4.10.1.0 parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1
    bytestring-0.10.8.2 containers-0.5.10.2 binary-0.8.5.1
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1=ac5e6b578591765d59beabaa71c9486d
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
haddock-interfaces: /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html: /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bencode-0.6.0.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bencode
version: 0.6.0.0
id: bencode-0.6.0.0-Jw8er8rrhuMEfRxBrsU6mL
key: bencode-0.6.0.0-Jw8er8rrhuMEfRxBrsU6mL
license: BSD3
copyright: (c) 2005-2009, David Himmelstrup,
           2006 Lemmih <lemmih@gmail.com>,
           2005 Jesper Louis Andersen <jlouis@mongers.org>
maintainer: Christopher Reichert <creichert07@gmail.com>
synopsis: Parser and printer for bencoded data.
description:
    Parser and printer for bencoded data.
    .
    Bencode (pronounced like B encode) is the encoding used by the
    peer-to-peer file sharing system BitTorrent for storing and
    transmitting loosely structured data.
category: Text
author: Lemmih (lemmih@gmail.com), Jesper Louis Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
abi: a7a294f57233fa232a04ea988e4cf470
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/bencode-0.6.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/bencode-0.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/bencode-0.6.0.0
hs-libraries: HSbencode-0.6.0.0-Jw8er8rrhuMEfRxBrsU6mL
depends:
    base-4.10.1.0 parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
    bytestring-0.10.8.2 containers-0.5.10.2 binary-0.8.5.1
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=de60442ea6c5324e39bc534a733c07dd
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
haddock-interfaces: /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html: /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
